@@ -7,17 +7,17 @@ class D2SquarePCA:
     def fit(self, X):
         X = np.asarray(X)
         mean = np.mean(X, 0)
-        mean_subtracted = X - mean
 
         line_no = X.shape[0]
         height = X.shape[1]
         width = X.shape[2]
-        row_covarience_matrix = np.zeros((height, height))
-        column_covarience_matrix = np.zeros((width, width))
+        row_covarience_matrix = np.zeros((width, width))
+        column_covarience_matrix = np.zeros((height, height))
 
         for i in range(line_no):
-            row_covarience_matrix += np.dot(mean_subtracted[i].T, mean_subtracted[i])
-            column_covarience_matrix += np.dot(mean_subtracted[i], mean_subtracted[i].T)
+            mean_subtracted = X[i] - mean
+            row_covarience_matrix += np.dot(mean_subtracted.T, mean_subtracted)
+            column_covarience_matrix += np.dot(mean_subtracted, mean_subtracted.T)
 
         row_covarience_matrix /= line_no
         column_covarience_matrix /= line_no
@@ -34,11 +34,13 @@ class D2SquarePCA:
 
     def transform(self, data):
         temp = np.dot(data, self.bases_row)
-        line_no = data.shape[0]
-
-        transform_data = np.zeros((line_no, self.n_components_2, self.n_components))
-        for i in range(line_no):
-            transform_data[i, :, :] = np.dot(self.bases_column.T, temp[i])
+        if len(data.shape) == 2:
+            transform_data = np.dot(self.bases_column.T, temp)
+        else:
+            line_no = data.shape[0]
+            transform_data = np.zeros((line_no, self.n_components_2, self.n_components))
+            for i in range(line_no):
+                transform_data[i, :, :] = np.dot(self.bases_column.T, temp[i])
         return transform_data
 
     def __init__(self, n_components, n_components_2=None):
